@@ -39,7 +39,7 @@ sub read_config {
   my $config_content = $self->slurp_file($config_file);
   
   $config = eval $config_content
-    or confess "Can't parse config file \"$config_file\"";
+    or confess "Can't parse config file \"$config_file\":$@$!";
     
   unless (ref $config eq 'HASH') {
     confess "\"$config_file\" must end with hash reference";
@@ -102,7 +102,7 @@ sub create_website_from_proto {
   my ($self, $home_dir, $module_name) = @_;
   
   unless (defined $home_dir) {
-    confess "Home directory must be specifed\n";
+    confess "Home directory must be specified\n";
   }
   
   if (-f $home_dir) {
@@ -157,6 +157,16 @@ sub create_website_from_proto {
     },
     $proto_dir
   );
+  
+  # git init repository directory
+  my @git_init_cmd_rep = ('git', 'init', $home_dir);
+  system(@git_init_cmd_rep) == 0
+    or confess "Can't execute command : @git_init_cmd_rep: $!";
+  
+  # git init public directory
+  my @git_init_cmd_public = ('git', 'init', "$home_dir/public");
+  system(@git_init_cmd_public) == 0
+    or confess "Can't execute command : @git_init_cmd_public: $!";
 }
 
 sub rel_file {
@@ -316,6 +326,7 @@ sub parse_giblog_syntax {
     
     # Escape >, < in pre tag
     if ($pre_start) {
+      $line =~ s/&/&amp;/g;
       $line =~ s/>/&gt;/g;
       $line =~ s/</&lt;/g;
       $content .= "$line\n";
@@ -362,6 +373,125 @@ sub parse_title {
   }
 }
 
+sub add_base_path_to_content {
+  my ($self, $data) = @_;
+  
+  # Giblog
+  my $giblog = $self->giblog;
+  
+  # Config
+  my $config = $giblog->config;
+  
+  # Base path
+  my $base_path = $config->{base_path};
+  if (defined $base_path) {
+    $self->_check_base_path($base_path);
+    
+    # Content
+    my $content = $data->{content};
+
+    # Add base path
+    my @lines = split /\n/, $content;
+    my $pre_start;
+    $content = '';
+    my $bread_end;
+    for my $line (@lines) {
+      my $original_line = $line;
+      
+      # Pre end
+      if ($line =~ m|^</pre\b|) {
+        $pre_start = 0;
+      }
+      
+      # Don't add base path in pre tag
+      if ($pre_start) {
+        $content .= "$line\n";
+      }
+      # Add base path to absolute path
+      else {
+        # Add base path to href absolute path
+        $line =~ s/\bhref\s*=\s*"(\/[^"]*?)"/href="$base_path$1"/g;
+        
+        # Add base path to src absolute path
+        $line =~ s/\bsrc\s*=\s*"(\/[^"]*?)"/src="$base_path$1"/g;
+        
+        $content .= "$line\n";
+      }
+      
+      # Pre start
+      if ($original_line =~ m|^<pre\b|) {
+        $pre_start = 1
+      }
+    }
+    
+    $data->{content} = $content;
+  }
+}
+
+sub add_base_path_to_public_css_files {
+  my ($self) = @_;
+  
+  # Giblog
+  my $giblog = $self->giblog;
+  
+  # Config
+  my $config = $giblog->config;
+  
+  # Base path
+  my $base_path = $config->{base_path};
+  if (defined $base_path) {
+    
+    $self->_check_base_path($base_path);
+    
+    my $public_dir = $self->rel_file('public');
+    
+    # Add base path to css file
+    find(
+      {
+        wanted => sub {
+          my $public_file = $File::Find::name;
+          
+          # Skip directory
+          return if -d $public_file;
+          
+          # Skip not css file
+          return unless $public_file =~ /\.css$/;
+          
+          # Open read-write mode
+          open my $fh, "+<", $public_file
+            or confess "Can't open \"$public_file\": $!";
+          
+          # Get content
+          my $content = $self->slurp_file($public_file);
+          
+          # Add base path to href absolute path
+          $content =~ s/\burl\s*\(\s*(\/[^\)]*?)\)/url($base_path$1)/g;
+          
+          print $fh encode('UTF-8', $content)
+            or confess "Can't write content to $public_file: $!";
+          
+          close $fh
+            or confess "Can't close file hanlde $public_file: $!";
+        },
+        no_chdir => 1,
+      },
+      $public_dir
+    );
+  }
+}
+
+sub _check_base_path {
+  my ($self, $base_path) = @_;
+  
+  # Check base path
+  unless ($base_path =~ /^\//) {
+    confess "base_path must start /";
+  }
+  if ($base_path =~ /\/$/) {
+    confess "base_path must end not /";
+  }
+}
+
 sub parse_title_from_first_h_tag {
   my ($self, $data) = @_;
   
@@ -469,12 +599,16 @@ sub parse_description_from_first_p_tag {
   # Create description from first p tag
   if ($content =~ m|<\s?p\b[^>]*?>(.*?)<\s?/\s?p\s?>|s) {
     my $description = $1;
+    
     # remove tag
-    $description =~ s/<.*?>//g;
+    $description =~ s/<[^<]*?>//g;
     
     # trim space
     $description =~ s/^\s+//;
     $description =~ s/\s+$//;
+
+    # remove new lines
+    $description =~ s/\n//g;
     
     $data->{'description'} = $description;
   }
@@ -639,8 +773,23 @@ sub write_to_public_file {
   my $public_dir = dirname $public_file;
   mkpath $public_dir;
   
+  # Need update public file
+  my $is_need_update_public_file;
+  if (!-f $public_file) {
+    $is_need_update_public_file = 1;
+  }
+  else {
+    # Get original content
+    my $original_content = $self->slurp_file($public_file);
+    unless ($content eq $original_content) {
+      $is_need_update_public_file = 1;
+    }
+  }
+  
   # Write to public file
-  $self->write_to_file($public_file, $content);
+  if ($is_need_update_public_file) {
+    $self->write_to_file($public_file, $content);
+  }
 }
 
 1;
@@ -776,15 +925,22 @@ If module name is "Giblog::Command::new_foo" and the loading path is "lib/Giblog
 
 Module must be loaded before calling "create_website_from_proto". otherwise exception occur.
 
-If home directory is not specific, exception occur.
+The web site directry is initialized by git and C<public> direcotry is also initialized by git.
 
-If home directory already exists, exception occur.
+  git init foo
+  git init foo/public 
+  
+If home directory is not specific, a exception occurs.
 
-If creating directory fail, exception occur.
+If home directory already exists, a exception occurs.
 
-If proto directory corresponding to module name is not specific, exception occur.
+If creating directory fail, a exception occurs.
 
-If proto direcotry corresponding to module name is not found, exception occur.
+If proto directory corresponding to module name is not specific, a exception occurs.
+
+If proto direcotry corresponding to module name is not found, a exception occurs.
+
+If git command is not found, a exception occurs.
 
 =head2 copy_static_files_to_public
 
@@ -895,7 +1051,7 @@ Add p tag to inline element starting from the beginning of line.
 
 Empty line is deleted.
 
-=item 2. Escape E<gt>, E<lt> in pre tag
+=item 2. Escape E<gt>, E<lt>, & in pre tag
 
 If pre tag starts at the beginning of the line and its end tag starts at the beginning of the line, execute HTML escapes ">" and "<" between them.
   
@@ -906,7 +1062,7 @@ If pre tag starts at the beginning of the line and its end tag starts at the beg
 
   # Output
   <pre>
-  my $foo = 1 &gt; 3 && 2 &lt; 5;
+  my $foo = 1 &gt; 3 &amp;&amp; 2 &lt; 5;
   </pre>
 
 =back
@@ -1314,3 +1470,5 @@ B<INPUT:>
 
   $data->{content}
   $data->{file}
+
+If the original content of the file is same as the new content of the file is same, this method don't write to public file. This means file time stamp is not be updated.
